<?php

namespace Drupal\mailchimp_ecommerce\Commands;

use Drush\Commands\DrushCommands;

/**
 * Provide drush commands for Mailchimp E-Commerce.
 */
class MailchimpEcommerceCommands extends DrushCommands {

  /**
   * Drush command to retrieve one or more Mailchimp E-Commerce stores.
   *
   * @param string $store_id
   *   The store ID.
   *
   * @command mailchimp-ecommerce:store
   * @usage drush mailchimp-ecommerce:store
   * @aliases mcec:store, mailchimp-ecommerce-store, mcecstore
   * @validate-module-enabled mailchimp_ecommerce
   */
  public function store(?string $store_id = NULL) {
    $api = \Drupal::service('mailchimp_ecommerce.store_handler');

    $this->output()->writeln("");
    if ($store_id !== NULL) {
      $store = $api->getStore($store_id);
      $this->output()->writeln("ID: " . $store->id);
      $this->output()->writeln("Name: " . $store->name);
      $this->output()->writeln("Audience ID: " . $store->list_id);
      $this->output()->writeln("Platform: " . $store->platform);
      $this->output()->writeln("");
    }
    else {
      $stores = $api->getStores();
      foreach ($stores->stores as $store) {
        $this->output()->writeln("ID: " . $store->id);
        $this->output()->writeln("Name: " . $store->name);
        $this->output()->writeln("Audience ID: " . $store->list_id);
        $this->output()->writeln("Platform: " . $store->platform);
        $this->output()->writeln("");
      }
    }
  }

}
